import { OnInit } from '@angular/core';
import { Location } from '@angular/common';
import { ImUser } from '../entity/im-user';
import { ChatService } from '../service/chat.service';
import { ViStompService } from '../common/service/vi.stomp.service';
import { ImWindow } from '../entity/im-window';
import { ImChatWindowComponent } from '../im-chat-window/im-chat-window.component';
import { MatSnackBar } from '@angular/material';
import { MessageService } from '../service/message.service';
import { CollectionViewer, SelectionChange } from '@angular/cdk/collections';
import { FlatTreeControl } from '@angular/cdk/tree';
import { BehaviorSubject, Observable } from 'rxjs';
/** Flat node with expandable and level information */
export declare class DynamicFlatNode {
    type: any;
    node: Array<string> | ImUser | ImWindow;
    level: number;
    expandable: boolean;
    isLoading: boolean;
    id: string;
    name: string;
    icon: string;
    count: number;
    messageContent: string;
    createTime: any;
    friendId: string;
    constructor(type: any, node: Array<string> | ImUser | ImWindow, level?: number, expandable?: boolean, isLoading?: boolean);
}
/**
 * File database, it can build a tree structured Json object from string.
 * Each node in Json object represents a file or a directory. For a file, it has filename and type.
 * For a directory, it has filename and children (a list of files or directories).
 * The input will be a json object string, and the output is a list of `FileNode` with nested
 * structure.
 */
export declare class DynamicDataSource {
    private treeControl;
    private chatService;
    dataChange: BehaviorSubject<DynamicFlatNode[]>;
    data: DynamicFlatNode[];
    constructor(treeControl: FlatTreeControl<DynamicFlatNode>, chatService: ChatService);
    connect(collectionViewer: CollectionViewer): Observable<DynamicFlatNode[]>;
    /** Handle expand/collapse behaviors */
    handleTreeControl(change: SelectionChange<DynamicFlatNode>): void;
    /**
     * Toggle the node, remove from display list
     */
    toggleNode(node: DynamicFlatNode, expand: boolean): void;
}
export declare class ImChatViewComponent implements OnInit {
    private _stompService;
    private chatService;
    snackBar: MatSnackBar;
    private location;
    private messageService;
    user: ImUser;
    chatWindowView: ImChatWindowComponent;
    treeControl: FlatTreeControl<DynamicFlatNode>;
    dataSource: DynamicDataSource;
    rootLevelNodes: string[][];
    initialData(): DynamicFlatNode[];
    constructor(_stompService: ViStompService, chatService: ChatService, snackBar: MatSnackBar, location: Location, messageService: MessageService);
    getLevel: (node: DynamicFlatNode) => number;
    isExpandable: (node: DynamicFlatNode) => boolean;
    hasChild: (_: number, _nodeData: DynamicFlatNode) => boolean;
    isImageUrl: (url: string) => boolean;
    ngOnInit(): void;
    goBack(): void;
    chatWindow(node: DynamicFlatNode): void;
    close(): void;
}
